camelot.camelot.view.controls.filter

Package camelot :: Package camelot :: Package view :: Package controls :: Module filter |
[hide private]
[frames] | no frames]

# Module filter

source code

Controls to filter data

Classes | [hide private]
| FilterList A list with filters that can be applied on a query in the tableview

Functions | [hide private]
_(x) | source code

Variables | [hide private]
| logger = `logging.getLogger('camelot.view.controls.filter')`